phoenix_function_timer

Macro phoenix_function_timer 

macro_rules! phoenix_function_timer {
    ($function_timer:ident, $nb_element:expr, $func_call_bench:expr) => { ... };
}
A macro to call properly the evaluation function for you

Parameters

  • function_timer : PFunctionTimer to be used to measure performances of the given func_call_bench
  • nb_element : number of elements processed
  • func_call_bench : function to be benchmarked

Errors

Panic if nb_test_perf == 0