PFunctionTimer

Struct PFunctionTimer 

pub struct PFunctionTimer { /* private fields */ }
Timer of a function to make nice benchmark automatically

Implementations

Source

impl PFunctionTimer

pub fn new( nb_measure: usize, nb_call_per_measure: usize, vec_nb_element: &Vec<usize>, ) -> Self

Constructor of the PFunctionTimer

Parameters
  • nb_measure : number of measure for each performance point
  • nb_call_per_measure : number of function calls per measure for each performance point
  • vec_nb_element : vector of all number of element to measure function performance
pub fn set_function_name(&mut self, function_name: &String)

Set the name of the function to be evaluated

Parameters
  • function_name : name of the function to be evaluated
pub fn add_time_perf(&mut self, time_perf: &PEllapsedTime)

Add a time performance of the function

Parameters
  • time_perf : time performance of the function
pub fn get_nb_measure(&self) -> usize

Get the number of measure per function perf evaluation

Returns

Number of measure per function perf evaluation

pub fn get_function_name(&self) -> &String

Get the evaluated function name

Returns

Evaluated function name

pub fn get_nb_call_per_measure(&self) -> usize

Get the number of function calls per measure per function perf evaluation

Returns

Number of function calls measure per function perf evaluation

pub fn get_vec_nb_element(&self) -> &Vec<usize>

Get the vector of the number of element to be treated per measure

Returns

Vector of the number of element to be treated per measure

pub fn eval_perf(&mut self, call_timer_eval_function: &dyn Fn(&mut Self, usize))

Do the full performance evaluation on all vector size

Parameters
  • call_timer_eval_function : function to call which evaluates performance for a given number of elements
pub fn save_gnuplot(&self, filename: &Path) -> Result<()>

Save performances in a gnuplot compatible file

Parameters
  • filename : text filename for gnuplot compatibility
Returns

I/O result